@@ -86,7 +86,3 @@ def getinput(title, options, result):
 # Displays text in a nice colourful format
 def display(text):
     print(f"{Colour.bracketsymbol}[{Colour.plussymbol}+{Colour.bracketsymbol}] {Colour.Reset}{text}\n")
-
-
-a = Menu(options=["11","2gsg2", "33dsfs", "4$sfd"])
-a.show()
